@@ -58,17 +58,25 @@ SystemMonitorService::SystemMonitorService(const char *name, QObject *parent)
       mMem(this)
 {
     if (mSettings.isCompelted()) {
+        qCDebug(app) << "Loading settings from configuration";
         mProtectionStatus = mSettings.getOptionValue(AlarmStatusOptionName).toBool();
         mAlarmCpuUsage = mSettings.getOptionValue(AlarmCpuUsageOptionName).toInt();
         mAlarmMemoryUsage = mSettings.getOptionValue(AlarmMemUsageOptionName).toInt();
         mAlarmInterval = mSettings.getOptionValue(AlarmIntervalOptionName).toInt();
         mLastAlarmTimeStamp = mSettings.getOptionValue(AlarmLastTimeOptionName).toLongLong();
+        qCDebug(app) << "Loaded settings - Protection:" << mProtectionStatus 
+                     << "CPU Alarm:" << mAlarmCpuUsage 
+                     << "Memory Alarm:" << mAlarmMemoryUsage 
+                     << "Interval:" << mAlarmInterval;
+    } else {
+        qCWarning(app) << "Failed to load settings, using default values";
     }
 
     // 初始化Cpu占用率
     mCpuUsage = static_cast<int>(mCpu.updateSystemCpuUsage());
     // 初始化Memory占用率
     mMemoryUsage = static_cast<int>(mMem.updateSystemMemoryUsage());
+    qCDebug(app) << "Initial system state - CPU:" << mCpuUsage << "% Memory:" << mMemoryUsage << "%";
 
     // 从配置文件，初始化： mProtectionStatus mAlarmInterval mAlarmCpuUsage mAlarmMemoryUsage
     mMoniterTimer.setInterval(MonitorTimeOut);
@@ -76,12 +84,14 @@ SystemMonitorService::SystemMonitorService(const char *name, QObject *parent)
 
     // 启动监测定时器
     mMoniterTimer.start();
+    qCInfo(app) << "Started monitoring timer with interval:" << MonitorTimeOut << "ms";
 
     QDBusConnection::RegisterOptions opts =
             QDBusConnection::ExportAllSlots | QDBusConnection::ExportAllSignals | QDBusConnection::ExportAllProperties;
 
     QDBusConnection::connectToBus(QDBusConnection::SessionBus, QString(name))
             .registerObject("/org/deepin/SystemMonitorDaemon", this, opts);
+    qCInfo(app) << "Registered DBus object at /org/deepin/SystemMonitorDaemon";
 }
 
 SystemMonitorService::~SystemMonitorService()
@@ -91,16 +101,14 @@ SystemMonitorService::~SystemMonitorService()
 bool SystemMonitorService::getSystemProtectionStatus()
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Get Protection Status:" << mProtectionStatus;
+    qCDebug(app) << "Get Protection Status:" << mProtectionStatus;
     return mProtectionStatus;
 }
 
 void SystemMonitorService::setSystemProtectionStatus(bool status)
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Set Protection Status:" << status;
+    qCDebug(app) << "Set Protection Status:" << status;
 
     if (mProtectionStatus != status) {
         mProtectionStatus = status;
@@ -108,38 +116,35 @@ void SystemMonitorService::setSystemProtectionStatus(bool status)
         mSettings.changedOptionValue(AlarmStatusOptionName, mProtectionStatus);
         // 监测设置变更，DBus信号
         emit alarmItemChanged(AlarmStatusOptionName, QDBusVariant(mProtectionStatus));
+        qCInfo(app) << "System protection status changed to:" << status;
     }
 }
 
 int SystemMonitorService::getCpuUsage()
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Get Cpu Usage:" << mCpuUsage;
+    qCDebug(app) << "Get CPU Usage:" << mCpuUsage << "%";
     return mCpuUsage;
 }
 
 int SystemMonitorService::getMemoryUsage()
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Get Memory Usage:" << mMemoryUsage;
+    qCDebug(app) << "Get Memory Usage:" << mMemoryUsage << "%";
     return mMemoryUsage;
 }
 
 int SystemMonitorService::getAlarmMsgInterval()
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Get Alarm Msg Interval:" << mAlarmInterval;
+    qCDebug(app) << "Get Alarm Message Interval:" << mAlarmInterval << "minutes";
     return mAlarmInterval;
 }
 
 void SystemMonitorService::setAlarmMsgInterval(int interval)
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Set Alarm Msg Interval:" << interval;
+    qCDebug(app) << "Set Alarm Message Interval:" << interval << "minutes";
 
     // 根据需求
     if (mSettings.isVaildValue(AlarmIntervalOptionName, interval)) {
@@ -148,8 +153,10 @@ void SystemMonitorService::setAlarmMsgInterval(int interval)
         mSettings.changedOptionValue(AlarmIntervalOptionName, mAlarmInterval);
         // 监测设置变更，DBus信号
         emit alarmItemChanged(AlarmIntervalOptionName, QDBusVariant(mAlarmInterval));
+        qCInfo(app) << "Alarm message interval changed to:" << interval << "minutes";
     } else {
         QPair<double, double> range = mSettings.getValueRange(AlarmIntervalOptionName);
+        qCWarning(app) << "Invalid alarm interval value:" << interval << "Valid range:" << range;
         sendErrorReply(QDBusError::NotSupported, QString("invalid value! value range[%1,%2]").arg(range.first).arg(range.second));
     }
 }
@@ -157,16 +164,14 @@ void SystemMonitorService::setAlarmMsgInterval(int interval)
 qint64 SystemMonitorService::getAlaramLastTimeInterval()
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Get Alarm Last Time:" << mLastAlarmTimeStamp;
+    qCDebug(app) << "Get Last Alarm Time:" << mLastAlarmTimeStamp;
     return mLastAlarmTimeStamp;
 }
 
 void SystemMonitorService::setAlaramLastTimeInterval(qint64 lastTime)
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Set Alarm Last Time:" << lastTime;
+    qCDebug(app) << "Set Last Alarm Time:" << lastTime;
 
     // 根据需求
     if (mSettings.isVaildValue(AlarmLastTimeOptionName, lastTime)) {
@@ -175,8 +180,10 @@ void SystemMonitorService::setAlaramLastTimeInterval(qint64 lastTime)
         mSettings.changedOptionValue(AlarmLastTimeOptionName, mLastAlarmTimeStamp);
         // 监测设置变更，DBus信号
         emit alarmItemChanged(AlarmLastTimeOptionName, QDBusVariant(mLastAlarmTimeStamp));
+        qCInfo(app) << "Last alarm time updated to:" << lastTime;
     } else {
         QPair<double, double> range = mSettings.getValueRange(AlarmLastTimeOptionName);
+        qCWarning(app) << "Invalid last alarm time value:" << lastTime << "Valid range:" << range;
         sendErrorReply(QDBusError::NotSupported, QString("invalid value! value range[%1,%2]").arg(range.first).arg(range.second));
     }
 }
@@ -184,16 +191,14 @@ void SystemMonitorService::setAlaramLastTimeInterval(qint64 lastTime)
 int SystemMonitorService::getAlarmUsageOfCpu()
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Get Alarm Usage Of Cpu:" << mAlarmCpuUsage;
+    qCDebug(app) << "Get CPU Alarm Threshold:" << mAlarmCpuUsage << "%";
     return mAlarmCpuUsage;
 }
 
 void SystemMonitorService::setAlarmUsageOfCpu(int usage)
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Set Alarm Usage Of Cpu:" << usage;
+    qCDebug(app) << "Set CPU Alarm Threshold:" << usage << "%";
 
     // 根据需求
     if (mSettings.isVaildValue(AlarmCpuUsageOptionName, usage)) {
@@ -202,8 +207,10 @@ void SystemMonitorService::setAlarmUsageOfCpu(int usage)
         mSettings.changedOptionValue(AlarmCpuUsageOptionName, mAlarmCpuUsage);
         // 监测设置变更，DBus信号
         emit alarmItemChanged(AlarmCpuUsageOptionName, QDBusVariant(mAlarmCpuUsage));
+        qCInfo(app) << "CPU alarm threshold changed to:" << usage << "%";
     } else {
         QPair<double, double> range = mSettings.getValueRange(AlarmCpuUsageOptionName);
+        qCWarning(app) << "Invalid CPU alarm threshold:" << usage << "Valid range:" << range;
         sendErrorReply(QDBusError::NotSupported, QString("invalid value! value range[%1,%2]").arg(range.first).arg(range.second));
     }
 }
@@ -211,16 +218,14 @@ void SystemMonitorService::setAlarmUsageOfCpu(int usage)
 int SystemMonitorService::getAlarmUsageOfMemory()
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Get Alarm Usage Of Memory:" << mAlarmMemoryUsage;
+    qCDebug(app) << "Get Memory Alarm Threshold:" << mAlarmMemoryUsage << "%";
     return mAlarmMemoryUsage;
 }
 
 void SystemMonitorService::setAlarmUsageOfMemory(int usage)
 {
     PrintDBusCaller()
-                    qCDebug(app)
-            << __FUNCTION__ << __LINE__ << " Set Alarm Usage Of Memory:" << usage;
+    qCDebug(app) << "Set Memory Alarm Threshold:" << usage << "%";
 
     // 根据需求
     if (mSettings.isVaildValue(AlarmMemUsageOptionName, usage)) {
@@ -229,8 +234,10 @@ void SystemMonitorService::setAlarmUsageOfMemory(int usage)
         mSettings.changedOptionValue(AlarmMemUsageOptionName, mAlarmMemoryUsage);
         // 监测设置变更，DBus信号
         emit alarmItemChanged(AlarmMemUsageOptionName, QDBusVariant(mAlarmMemoryUsage));
+        qCInfo(app) << "Memory alarm threshold changed to:" << usage << "%";
     } else {
         QPair<double, double> range = mSettings.getValueRange(AlarmMemUsageOptionName);
+        qCWarning(app) << "Invalid memory alarm threshold:" << usage << "Valid range:" << range;
         sendErrorReply(QDBusError::NotSupported, QString("invalid value! value range[%1,%2]").arg(range.first).arg(range.second));
     }
 }
@@ -239,13 +246,13 @@ void SystemMonitorService::showDeepinSystemMoniter()
 {
     PrintDBusCaller()
 
-            QString cmd("gdbus call -e -d  com.deepin.SystemMonitorServer -o /com/deepin/SystemMonitorServer -m com.deepin.SystemMonitorServer.showDeepinSystemMoniter");
+    QString cmd("gdbus call -e -d  com.deepin.SystemMonitorServer -o /com/deepin/SystemMonitorServer -m com.deepin.SystemMonitorServer.showDeepinSystemMoniter");
     QTimer::singleShot(100, this, [=]() { QProcess::startDetached(cmd); });
 }
 
 void SystemMonitorService::changeAlarmItem(const QString &item, const QDBusVariant &value)
 {
-    qCDebug(app) << __FUNCTION__ << __LINE__ << ", item:" << item << ", value:" << value.variant();
+    qCDebug(app) << "Changing alarm item:" << item << "to value:" << value.variant();
     if (mSettings.itemKeys().contains(item) && mSettings.isVaildValue(item, value.variant())) {
         if (mSettings.isVaildValue(item, value.variant())) {
             if (item == AlarmStatusOptionName) {
@@ -259,11 +266,14 @@ void SystemMonitorService::changeAlarmItem(const QString &item, const QDBusVaria
             }
             // 更改设置文件
             mSettings.changedOptionValue(item, value.variant());
+            qCInfo(app) << "Successfully changed alarm item:" << item << "to:" << value.variant();
         } else {
             QPair<double, double> range = mSettings.getValueRange(item);
+            qCWarning(app) << "Invalid value for" << item << ":" << value.variant() << "Valid range:" << range;
             sendErrorReply(QDBusError::NotSupported, QString("invalid value! value range[%1,%2]").arg(range.first).arg(range.second));
         }
     } else {
+        qCWarning(app) << "Invalid alarm item:" << item;
         sendErrorReply(QDBusError::NotSupported, QString("invalid item(%1) !").arg(item));
     }
 }
@@ -275,6 +285,7 @@ bool SystemMonitorService::checkCpuAlarm()
     qint64 timeGap = 1000 * 60 * mAlarmInterval;
 
     if (mCpuUsage >= mAlarmCpuUsage && diffTime >= timeGap) {
+        qCInfo(app) << "CPU usage alarm triggered - Usage:" << mCpuUsage << "% Threshold:" << mAlarmCpuUsage << "%";
         mLastAlarmTimeStamp = curTimeStamp;
         QString cmd = QString("gdbus call -e -d  com.deepin.SystemMonitorServer -o /com/deepin/SystemMonitorServer -m com.deepin.SystemMonitorServer.showCpuAlarmNotify \"%1\" ").arg(QString::number(mCpuUsage));
         QTimer::singleShot(100, this, [=]() {
@@ -287,6 +298,7 @@ bool SystemMonitorService::checkCpuAlarm()
             process.start("gdbus", args);
             process.waitForFinished(5000);
             if (process.exitCode() != 0) {
+                qCWarning(app) << "Failed to show CPU alarm notification, retrying...";
                 process.start("gdbus", args);
                 process.waitForFinished(5000);
             }
@@ -303,6 +315,7 @@ bool SystemMonitorService::checkMemoryAlarm()
     qint64 timeGap = 1000 * 60 * mAlarmInterval;
 
     if (mMemoryUsage >= mAlarmMemoryUsage && diffTime > timeGap) {
+        qCInfo(app) << "Memory usage alarm triggered - Usage:" << mMemoryUsage << "% Threshold:" << mAlarmMemoryUsage << "%";
         mLastAlarmTimeStamp = curTimeStamp;
         QString cmd = QString("gdbus call -e -d  com.deepin.SystemMonitorServer -o /com/deepin/SystemMonitorServer -m com.deepin.SystemMonitorServer.showMemoryAlarmNotify \"%1\" ").arg(QString::number(mMemoryUsage));
         QTimer::singleShot(100, this, [=]() {
@@ -315,6 +328,7 @@ bool SystemMonitorService::checkMemoryAlarm()
             process.start("gdbus", args);
             process.waitForFinished(5000);
             if (process.exitCode() != 0) {
+                qCWarning(app) << "Failed to show memory alarm notification, retrying...";
                 process.start("gdbus", args);
                 process.waitForFinished(5000);
             }
@@ -329,6 +343,7 @@ void SystemMonitorService::onMonitorTimeout()
     // 获取CPU和内存占用
     mCpuUsage = static_cast<int>(mCpu.updateSystemCpuUsage());
     mMemoryUsage = static_cast<int>(mMem.updateSystemMemoryUsage());
+    qCDebug(app) << "System state updated - CPU:" << mCpuUsage << "% Memory:" << mMemoryUsage << "%";
 
     // 进行警报检测
     if (mProtectionStatus) {
