@@ -22,7 +22,7 @@ extern "C" {
 #include <QFile>
 #include <QTextStream>
 #include <QProcess>
-
+#include <QRegularExpression>
 #include <ctype.h>
 #include <errno.h>
 #include <sched.h>
@@ -67,6 +67,27 @@ static float first_avaliable_cur_freq(struct lscpu_cxt *cxt, const struct lscpu_
 
     return 0.0f;
 }
+// 取所有CPU频率有效值中最大值
+static float max_avaliable_cur_freq(struct lscpu_cxt *cxt, const struct lscpu_cputype *ct)
+{
+    if (!cxt)
+        return 0.0f;
+
+    size_t i;
+    float res = 0.0f;
+
+    for (i = 0; i < cxt->npossibles; i++) {
+        struct lscpu_cpu *cpu = cxt->cpus[i];
+
+        if (!cpu || cpu->type != ct || !is_cpu_present(cxt, cpu))
+            continue;
+        if (cpu->mhz_cur_freq <= 0.0f)
+            continue;
+        res = max(res, cpu->mhz_cur_freq);
+    }
+
+    return res;
+}
 
 static void lscpu_free_context(struct lscpu_cxt *cxt)
 {
@@ -295,10 +316,12 @@ CPUSet::CPUSet()
     : d(new CPUSetPrivate())
 {
 }
+
 CPUSet::CPUSet(const CPUSet &other)
     : d(other.d)
 {
 }
+
 CPUSet &CPUSet::operator=(const CPUSet &rhs)
 {
     if (this == &rhs)
@@ -469,9 +492,9 @@ void CPUSet::read_stats()
     int nr;
 
     if (!(fp = fopen(PROC_PATH_STAT, "r"))) {
-        print_errno(errno, QString("open %1 failed").arg(PROC_PATH_STAT));
+        qCWarning(app) << "Failed to open" << PROC_PATH_STAT << ":" << strerror(errno);
         return;
-    }   // ::if(fopen)
+    }
     fPtr.reset(fp);
 
     while (fgets(line.data(), BUFSIZ, fp)) {
@@ -509,10 +532,11 @@ void CPUSet::read_stats()
                         d->m_usage->cpu = cpu;
                         d->m_usage->total = d->m_stat->user + d->m_stat->nice + d->m_stat->sys + d->m_stat->idle + d->m_stat->iowait + d->m_stat->hardirq + d->m_stat->softirq + d->m_stat->steal;
                         d->m_usage->idle = d->m_stat->idle + d->m_stat->iowait;
-                    }   // ::if(usage)
-                } else
-                    print_errno(errno, QString("read %1 failed, cpu").arg(PROC_PATH_STAT));
-            }   // ::if(m_stat)
+                    }
+                } else {
+                    qCWarning(app) << "Failed to parse CPU stats from" << PROC_PATH_STAT;
+                }
+            }
         } else if (!strncmp(line.data(), "cpu", 3)) {
             // per cpu stat in jiffies
             auto stat = std::make_shared<struct cpu_stat_t>();
@@ -547,16 +571,14 @@ void CPUSet::read_stats()
 
                         d->m_statDB[stat->cpu] = stat;
                         d->m_usageDB[usage->cpu] = usage;
-                    }   //::if(usage)
-
-                } else
-                    print_errno(errno, QString("read %1 failed, cpu%2").arg(PROC_PATH_STAT).arg(ncpu));
-            }   // ::if(stat)
+                    }
+                } else {
+                    qCWarning(app) << "Failed to parse CPU" << ncpu << "stats from" << PROC_PATH_STAT;
+                }
+            }
         } else if (!strncmp(line.data(), "btime", 5)) {
             // read boot time in seconds since epoch
-            struct timeval btime
-            {
-            };
+            struct timeval btime {};
             long nsec {};
             int nm = sscanf(line.data() + 5, "%ld", &nsec);
             if (nm == 1) {
@@ -570,8 +592,9 @@ void CPUSet::read_stats()
         }   // ::if(btime)
     }   // ::while(fgets)
 
-    if (ferror(fp))
-        print_errno(errno, QString("read %1 failed").arg(PROC_PATH_STAT));
+    if (ferror(fp)) {
+        qCWarning(app) << "Error reading" << PROC_PATH_STAT << ":" << strerror(errno);
+    }
 }
 
 void CPUSet::read_overall_info()
@@ -582,11 +605,19 @@ void CPUSet::read_overall_info()
     process.start("cat /proc/cpuinfo");
     process.waitForFinished(3000);
     QString cpuinfo = process.readAllStandardOutput();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QStringList processors = cpuinfo.split("\n\n", QString::SkipEmptyParts);
+#else
+    QStringList processors = cpuinfo.split("\n\n", Qt::SkipEmptyParts);
+#endif
 
     for (int i = 0; i < processors.count(); ++i) {
         CPUInfo info;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QStringList list = processors[i].split("\n", QString::SkipEmptyParts);
+#else
+        QStringList list = processors[i].split("\n", Qt::SkipEmptyParts);
+#endif
         for (QString text : list) {
             if (text.startsWith("processor")) {
                 info.setIndex(text.split(":").value(1).toInt());
@@ -650,11 +681,11 @@ void CPUSet::read_dmi_cache_info()
     //(specialComType>=1)如果是hw机型,略过之前的判断
     qCInfo(app) << "common::specialComType value is:" << specialComType;
     if (specialComType == 0) {
+        qCDebug(app) << "Skipping DMI cache info for non-special computer type";
         return;
     } else if (specialComType <= -1) {
-        qCInfo(app) << "use dmidecode check board type!";
-        process.start("dmidecode", QStringList() << "-s"
-                                                 << "system-product-name");
+        qCInfo(app) << "Using dmidecode to check board type";
+        process.start("dmidecode", QStringList() << "-s" << "system-product-name");
         process.waitForFinished(-1);
         QString spnInfo = process.readAllStandardOutput();
         if (!spnInfo.contains("KLVV", Qt::CaseInsensitive) && !spnInfo.contains("L540", Qt::CaseInsensitive) && !spnInfo.contains("KLVU", Qt::CaseInsensitive)
@@ -674,19 +705,24 @@ void CPUSet::read_dmi_cache_info()
             if (!result.contains("PWC30", Qt::CaseInsensitive)   //w525
                 && !result.contains("PGUX", Qt::CaseInsensitive)) {
                 process.close();
+                qCDebug(app) << "Not a special computer type, skipping DMI cache info";
                 return;
             }
         }
     }
-    qCInfo(app) << "Current is special computer type!";
+    qCInfo(app) << "Processing DMI cache info for special computer type";
 
-    process.start("dmidecode", QStringList() << "-t"
-                                             << "cache");
+    process.start("dmidecode", QStringList() << "-t" << "cache");
     process.waitForFinished(-1);
     QString cacheinfo = process.readAllStandardOutput();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QStringList caches = cacheinfo.split("\n\n", QString::SkipEmptyParts);
+#else
+    QStringList caches = cacheinfo.split("\n\n", Qt::SkipEmptyParts);
+#endif
     process.close();
 
+    qCDebug(app) << "Found" << caches.size() << "cache entries in DMI information";
     QList<QMap<QString, QString>> mapInfos;
     foreach (const QString &item, caches) {
         if (item.isEmpty())
@@ -701,7 +737,11 @@ void CPUSet::read_dmi_cache_info()
 
             QStringList words = line.split(": ");
             if (1 == words.size() && words[0].endsWith(":")) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 lasKey = words[0].replace(QRegExp(":$"), "");
+#else
+                lasKey = words[0].replace(QRegularExpression(":$"), "");
+#endif
                 mapInfo.insert(lasKey.trimmed(), " ");
             } else if (1 == words.size() && !lasKey.isEmpty()) {
                 mapInfo[lasKey.trimmed()] += words[0];
@@ -717,7 +757,11 @@ void CPUSet::read_dmi_cache_info()
     for (auto &item : mapInfos) {
         if (!item.contains("Socket Designation") || !item.contains("Maximum Size"))
             continue;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QStringList strList = item["Maximum Size"].split(" ", QString::SkipEmptyParts);
+#else
+        QStringList strList = item["Maximum Size"].split(" ", Qt::SkipEmptyParts);
+#endif
         if (strList.size() != 2)
             continue;
 
@@ -756,7 +800,7 @@ void CPUSet::read_lscpu()
     struct lscpu_cxt *cxt;   // CPU信息
     cxt = reinterpret_cast<struct lscpu_cxt *>(xcalloc(1, sizeof(struct lscpu_cxt)));   // 初始化信息
     if (!cxt) {
-        qCWarning(app) << __FUNCTION__ << " lscpu_cxt Init Faild!";
+        qCWarning(app) << "Failed to initialize lscpu context";
         return;
     }
     /* set default cpu display mode if none was specified */
@@ -767,16 +811,18 @@ void CPUSet::read_lscpu()
 
     cxt->syscpu = ul_new_path(_PATH_SYS_CPU);
     if (!cxt->syscpu) {
-        qCWarning(app) << __FUNCTION__ << "failed to initialize CPUs sysfs handler";
+        qCWarning(app) << "Failed to initialize CPUs sysfs handler";
         return;
     }
+
     if (cxt->prefix)
         ul_path_set_prefix(cxt->syscpu, cxt->prefix);
     cxt->procfs = ul_new_path("/proc");
     if (!cxt->procfs) {
-        qCWarning(app) << __FUNCTION__ << "failed to initialize procfs handler!";
+        qCWarning(app) << "Failed to initialize procfs handler";
         return;
     }
+
     if (cxt->prefix)
         ul_path_set_prefix(cxt->procfs, cxt->prefix);
 
@@ -910,8 +956,8 @@ void CPUSet::read_lscpu()
             d->m_info.insert("CPU max MHz", maxMHz);
             QString minMHz = QString::number(static_cast<double>(lsblk_cputype_get_minmhz(cxt, ct)), 'f', 4);
             d->m_info.insert("CPU min MHz", minMHz);
-            // 取首个CPU频率有效值
-            QString nowMHz = QString::number(static_cast<double>(first_avaliable_cur_freq(cxt, ct)), 'f', 4);
+            // 取所有CPU频率有效值中最大值
+            QString nowMHz = QString::number(static_cast<double>(max_avaliable_cur_freq(cxt, ct)), 'f', 4);
             if (scal == 0.0f) {
                 nowMHz = "-";
             }
@@ -937,7 +983,7 @@ void CPUSet::read_lscpu()
             d->m_info.insert("Flags", ct->flags);
         }
     } else {
-        qCWarning(app) << __FUNCTION__ << "ct init failed!";
+        qCWarning(app) << "Failed to get CPU type information";
         return;
     }
 
