@@ -1,8 +1,10 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="uk">
 <context>
     <name>Common.Search</name>
     <message>
-        <location filename="../gui/process_table_view.cpp" line="130"/>
+        <location filename="../gui/process_table_view.cpp" line="141"/>
         <source>No search results</source>
         <translation>Нічого не знайдено</translation>
     </message>
@@ -10,7 +12,7 @@
 <context>
     <name>Cpu.Widget</name>
     <message>
-        <location filename="../gui/cpu_widget.cpp" line="180"/>
+        <location filename="../gui/cpu_widget.cpp" line="193"/>
         <source>CPU</source>
         <translation>Процесор</translation>
     </message>
@@ -18,8 +20,9 @@
 <context>
     <name>CpuWidget</name>
     <message>
-        <location filename="../gui/cpu_widget.cpp" line="216"/>
-        <location filename="../gui/cpu_widget.cpp" line="217"/>
+        <location filename="../gui/cpu_widget.cpp" line="229"/>
+        <location filename="../gui/cpu_widget.cpp" line="231"/>
+        <location filename="../gui/cpu_widget.cpp" line="232"/>
         <source>Utilization</source>
         <translation>Вжиток</translation>
     </message>
@@ -27,49 +30,36 @@
 <context>
     <name>Disk.Widget</name>
     <message>
-        <location filename="../gui/disk_widget.cpp" line="228"/>
+        <location filename="../gui/disk_widget.cpp" line="242"/>
         <source>Disk</source>
         <translation>Диск</translation>
     </message>
     <message>
-        <location filename="../gui/disk_widget.cpp" line="258"/>
+        <location filename="../gui/disk_widget.cpp" line="276"/>
         <source>Read</source>
         <translation>Читання</translation>
     </message>
     <message>
-        <location filename="../gui/disk_widget.cpp" line="259"/>
+        <location filename="../gui/disk_widget.cpp" line="277"/>
         <source>Write</source>
         <translation>Запис</translation>
     </message>
 </context>
-<context>
-    <name>Help.Shortcut.System</name>
-    <message>
-        <location filename="../common/common.cpp" line="42"/>
-        <source>System</source>
-        <translation>Система</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="48"/>
-        <source>Display shortcuts</source>
-        <translation>Показати скорочення</translation>
-    </message>
-</context>
 <context>
     <name>Memory.Widget</name>
     <message>
-        <location filename="../gui/memory_widget.cpp" line="152"/>
+        <location filename="../gui/memory_widget.cpp" line="178"/>
         <source>Memory</source>
         <translation>Пам&apos;ять</translation>
     </message>
     <message>
-        <location filename="../gui/memory_widget.cpp" line="179"/>
-        <location filename="../gui/memory_widget.cpp" line="188"/>
+        <location filename="../gui/memory_widget.cpp" line="210"/>
+        <location filename="../gui/memory_widget.cpp" line="218"/>
         <source>Swap</source>
         <translation>Резервна пам&apos;ять</translation>
     </message>
     <message>
-        <location filename="../gui/memory_widget.cpp" line="180"/>
+        <location filename="../gui/memory_widget.cpp" line="211"/>
         <source>Not enabled</source>
         <translation>Не ввімкнено</translation>
     </message>
@@ -77,22 +67,22 @@
 <context>
     <name>Net.Widget</name>
     <message>
-        <location filename="../gui/net_widget.cpp" line="259"/>
+        <location filename="../gui/net_widget.cpp" line="271"/>
         <source>Download</source>
         <translation>Отримання</translation>
     </message>
     <message>
-        <location filename="../gui/net_widget.cpp" line="260"/>
+        <location filename="../gui/net_widget.cpp" line="272"/>
         <source>Total received</source>
         <translation>Загалом отримано</translation>
     </message>
     <message>
-        <location filename="../gui/net_widget.cpp" line="262"/>
+        <location filename="../gui/net_widget.cpp" line="274"/>
         <source>Total sent</source>
         <translation>Загалом надіслано</translation>
     </message>
     <message>
-        <location filename="../gui/net_widget.cpp" line="261"/>
+        <location filename="../gui/net_widget.cpp" line="273"/>
         <source>Upload</source>
         <translation>Надсилання</translation>
     </message>
@@ -100,8 +90,9 @@
 <context>
     <name>NetWidget</name>
     <message>
-        <location filename="../gui/net_widget.cpp" line="232"/>
-        <location filename="../gui/net_widget.cpp" line="235"/>
+        <location filename="../gui/net_widget.cpp" line="241"/>
+        <location filename="../gui/net_widget.cpp" line="243"/>
+        <location filename="../gui/net_widget.cpp" line="247"/>
         <source>Network</source>
         <translation>Мережа</translation>
     </message>
@@ -109,37 +100,37 @@
 <context>
     <name>Process.Priority</name>
     <message>
-        <location filename="../process/process.cpp" line="67"/>
+        <location filename="../process/process.cpp" line="54"/>
         <source>Very high</source>
         <translation>Дуже висока</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="68"/>
+        <location filename="../process/process.cpp" line="55"/>
         <source>High</source>
         <translation>Висока</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="69"/>
+        <location filename="../process/process.cpp" line="56"/>
         <source>Normal</source>
         <translation>Звичайна</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="70"/>
+        <location filename="../process/process.cpp" line="57"/>
         <source>Low</source>
         <translation>Низька</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="71"/>
+        <location filename="../process/process.cpp" line="58"/>
         <source>Very low</source>
         <translation>Дуже низька</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="72"/>
+        <location filename="../process/process.cpp" line="59"/>
         <source>Custom</source>
         <translation>Нетипова</translation>
     </message>
     <message>
-        <location filename="../process/process.cpp" line="73"/>
+        <location filename="../process/process.cpp" line="60"/>
         <source>Invalid</source>
         <translation>Некоректна</translation>
     </message>
@@ -147,32 +138,32 @@
 <context>
     <name>Process.Signal</name>
     <message>
-        <location filename="../process/process_db.cpp" line="162"/>
+        <location filename="../process/process_db.cpp" line="168"/>
         <source>Failed to end process</source>
         <translation>Не вдалося завершити процес</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="165"/>
+        <location filename="../process/process_db.cpp" line="171"/>
         <source>Failed to pause process</source>
         <translation>Не вдалося призупинити роботу процесу</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="168"/>
+        <location filename="../process/process_db.cpp" line="174"/>
         <source>Failed to resume process</source>
         <translation>Не вдалося відновити роботу процесу</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="171"/>
+        <location filename="../process/process_db.cpp" line="177"/>
         <source>Failed to kill process</source>
         <translation>Не вдалося примусово завершити роботу процесу</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="174"/>
+        <location filename="../process/process_db.cpp" line="180"/>
         <source>Unknown error</source>
         <translation>Невідома помилка</translation>
     </message>
     <message>
-        <location filename="../process/process_db.cpp" line="224"/>
+        <location filename="../process/process_db.cpp" line="239"/>
         <source>Failed in sending signal to process</source>
         <translation>Не вдалося надіслати процесу сигнал</translation>
     </message>
@@ -180,115 +171,80 @@
 <context>
     <name>Process.Table</name>
     <message>
-        <location filename="../model/process_table_model.cpp" line="175"/>
+        <location filename="../model/process_table_model.cpp" line="174"/>
         <source>No response</source>
         <translation>Немає відповіді</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.cpp" line="180"/>
+        <location filename="../model/process_table_model.cpp" line="179"/>
         <source>Suspend</source>
         <translation>Призупинити</translation>
     </message>
-    <message>
-        <location filename="../process/process_name.cpp" line="96"/>
-        <location filename="../process/process_name.cpp" line="103"/>
-        <location filename="../process/process_name.cpp" line="106"/>
-        <source>Tray</source>
-        <translation>Лоток</translation>
-    </message>
-</context>
-<context>
-    <name>Process.Table.Context.Menu</name>
-    <message>
-        <location filename="../common/common.cpp" line="76"/>
-        <source>End process</source>
-        <translation>Завершити процес</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="82"/>
-        <source>Suspend process</source>
-        <translation>Призупинити процес</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="88"/>
-        <source>Resume process</source>
-        <translation>Відновити роботу процесу</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="93"/>
-        <source>Properties</source>
-        <translation>Властивості</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="99"/>
-        <source>Kill process</source>
-        <translation>Вбити процес</translation>
-    </message>
 </context>
 <context>
     <name>Process.Table.Header</name>
     <message>
-        <location filename="../model/process_table_model.h" line="31"/>
+        <location filename="../model/process_table_model.h" line="16"/>
         <source>Name</source>
         <translation>Назва</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="33"/>
+        <location filename="../model/process_table_model.h" line="18"/>
         <source>CPU</source>
         <translation>ПРЦ</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="35"/>
+        <location filename="../model/process_table_model.h" line="20"/>
         <source>User</source>
         <translation>Користувач</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="37"/>
+        <location filename="../model/process_table_model.h" line="22"/>
         <source>Memory</source>
         <translation>Пам&apos;ять</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="38"/>
+        <location filename="../model/process_table_model.h" line="23"/>
         <source>Shared memory</source>
         <translation>Спільна пам&apos;ять</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="39"/>
+        <location filename="../model/process_table_model.h" line="24"/>
         <source>Virtual memory</source>
         <translation>Віртуальна пам&apos;ять</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="41"/>
+        <location filename="../model/process_table_model.h" line="26"/>
         <source>Upload</source>
         <translation>Надсилання</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="43"/>
+        <location filename="../model/process_table_model.h" line="28"/>
         <source>Download</source>
         <translation>Отримання</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="45"/>
+        <location filename="../model/process_table_model.h" line="30"/>
         <source>Disk read</source>
         <translation>Читання з диска</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="47"/>
+        <location filename="../model/process_table_model.h" line="32"/>
         <source>Disk write</source>
         <translation>Запис на диск</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="49"/>
+        <location filename="../model/process_table_model.h" line="34"/>
         <source>PID</source>
         <translation>PID</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="51"/>
+        <location filename="../model/process_table_model.h" line="36"/>
         <source>Nice</source>
         <translation>Ніцца</translation>
     </message>
     <message>
-        <location filename="../model/process_table_model.h" line="53"/>
+        <location filename="../model/process_table_model.h" line="38"/>
         <source>Priority</source>
         <translation>Пріоритетність</translation>
     </message>
@@ -296,18 +252,19 @@
 <context>
     <name>ProcessWidget</name>
     <message>
-        <location filename="../gui/process_widget.cpp" line="65"/>
+        <location filename="../gui/process_widget.cpp" line="219"/>
         <source>Name</source>
         <translation>Назва</translation>
     </message>
     <message>
-        <location filename="../gui/process_widget.cpp" line="72"/>
+        <location filename="../gui/process_widget.cpp" line="225"/>
         <source>CPU</source>
         <translation>Процесор</translation>
     </message>
     <message>
-        <location filename="../gui/process_widget.cpp" line="182"/>
-        <location filename="../gui/process_widget.cpp" line="185"/>
+        <location filename="../gui/process_widget.cpp" line="203"/>
+        <location filename="../gui/process_widget.cpp" line="205"/>
+        <location filename="../gui/process_widget.cpp" line="209"/>
         <source>Processes</source>
         <translation>Процеси</translation>
     </message>
@@ -315,61 +272,9 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../system/cpu_set.cpp" line="267"/>
+        <location filename="../system/cpu_set.cpp" line="253"/>
         <source>Not support</source>
         <translation>Немає підтримки</translation>
     </message>
 </context>
-<context>
-    <name>Service.Table.Context.Menu</name>
-    <message>
-        <location filename="../common/common.cpp" line="113"/>
-        <source>Start</source>
-        <translation>Запустити</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="118"/>
-        <source>Stop</source>
-        <translation>Зупинити</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="123"/>
-        <source>Restart</source>
-        <translation>Перезапустити</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="128"/>
-        <source>Refresh</source>
-        <translation>Оновити</translation>
-    </message>
-</context>
-<context>
-    <name>Title.Bar.Context.Menu</name>
-    <message>
-        <location filename="../common/common.cpp" line="69"/>
-        <source>Force end application</source>
-        <translation>Примусове завершення програми</translation>
-    </message>
-</context>
-<context>
-    <name>Title.Bar.Search</name>
-    <message>
-        <location filename="../common/common.cpp" line="54"/>
-        <source>Search</source>
-        <translation>Пошук</translation>
-    </message>
-</context>
-<context>
-    <name>Title.Bar.Switch</name>
-    <message>
-        <location filename="../common/common.cpp" line="63"/>
-        <source>Processes</source>
-        <translation>Процеси</translation>
-    </message>
-    <message>
-        <location filename="../common/common.cpp" line="108"/>
-        <source>Services</source>
-        <translation>Служби</translation>
-    </message>
-</context>
-</TS>
\ No newline at end of file
+</TS>
